@@ -1,4 +1,4 @@
-/* $Id: first.c,v 1.47 2004/06/09 18:52:20 bdejean Exp $ */
+/* $Id: first.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,10 @@
    Boston, MA 02111-1307, USA.
 */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <locale.h>
 #include <libintl.h>
 #include <stdio.h>
