@@ -1,4 +1,4 @@
-/* $Id: parameter.c,v 1.12 2004/06/06 22:10:29 bdejean Exp $ */
+/* $Id: parameter.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,8 +21,10 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/parameter.h>
+#include <glibtop/error.h>
 
 #define _write_data(ptr,size)	\
 	if ((data_ptr == NULL) || (data_size < size)) return -size; \
@@ -32,9 +34,9 @@
 
 #define _check_data(size)	\
 	if ((data_ptr == NULL) || (data_size != size)) { \
-		glibtop_warn_r (server, "glibtop_set_parameter (%d): " \
+		glibtop_warn_r (server, "glibtop_set_parameter (%u): " \
 				"Expected %lu bytes but got %lu.", \
-				parameter, size, data_size); \
+				(unsigned) parameter, (unsigned long) size, (unsigned long) data_size); \
 		return; \
 	}
 
@@ -82,7 +84,7 @@ glibtop_set_parameter_l (glibtop *server, const unsigned parameter,
 		break;
 	case GLIBTOP_PARAM_FEATURES:
 		/* You should not be allowed to set this field. */
-		glibtop_warn_r (server, "glibtop_set_parameter (%d): " \
+		glibtop_warn_r (server, "glibtop_set_parameter (%u): " \
 				"Cannot modify read-only value.",
 				parameter);
 		break;
