@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.6 2004/07/18 20:33:56 bdejean Exp $ */
+/* $Id: proclist.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <procinfo.h>
 
 #include <glibtop.h>
@@ -59,6 +60,8 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 	pid_t current;
 	int result;
 
+	glibtop_init_s (&server, (1L << GLIBTOP_SYSDEPS_PROCLIST), 0);
+
 	memset (buf, 0, sizeof (glibtop_proclist));
 
 	for( count = total = 0, current = 0
