@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: nosuid.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/close.h>
