@@ -1,4 +1,4 @@
-/* $Id: procmem.c,v 1.25 2004/09/23 08:13:28 bdejean Exp $ */
+/* $Id: procmem.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,10 +21,13 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procmem.h>
 
+#include "glibtop_private.h"
+
 static const unsigned long _glibtop_sysdeps_proc_mem =
 (1L << GLIBTOP_PROC_MEM_VSIZE) + (1L << GLIBTOP_PROC_MEM_RSS) +
 (1L << GLIBTOP_PROC_MEM_RSS_RLIM);
@@ -49,7 +52,7 @@ void
 glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf, pid_t pid)
 {
 	char buffer [BUFSIZ], *p;
-	const size_t pagesize = getpagesize();
+	const size_t pagesize = get_page_size();
 
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
 
