@@ -1,4 +1,4 @@
-/* $Id: shm_limits.c,v 1.19 2005/12/12 09:38:12 jamesh Exp $ */
+/* $Id: shm_limits.c 2464 2006-04-02 09:16:20Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -51,7 +51,7 @@ glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 
 	memset (buf, 0, sizeof (glibtop_shm_limits));
 
-	shmctl (0, IPC_INFO, (struct shmid_ds *) &shminfo);
+	shmctl (0, IPC_INFO, (void *) &shminfo);
 
 	buf->shmmax = shminfo.shmmax;
 	buf->shmmin = shminfo.shmmin;
